-----------------------------------------------------------
CSUMB's CST205 - A simple Image Class
-----------------------------------------------------------

This project offers students acces to a simple RGBImage class, which
is built on the use of the Image module in the PIL package. As PIL is no
longer updated for Python 3, this package relies on Pillow.



Python usage
-----------------------------------------------------------
The interface is meant to be as simple as possible. To import a class,
  import from SimpleImage. eg.

from simpleImage.ImageClass import rgbImage


Documentation
-----------------------------------------------------------
Some simple documentation is available at
http://pwalker91.github.io/CSUMB205_Image

Contributors
-----------------------------------------------------------
* Peter Walker https://github.com/pwalker91
-----------------------------------------------------------
